@@ -321,9 +321,9 @@ def test_get_trip_observations_export_single_vehicles():
             "blockId": ["503-1", "403-1"],
             "tripId": ["t_5561882_b_80157_tn_1", "t_5561912_b_80157_tn_0"],
             "tripShortName": ["t_5561882_b_80157_tn_1", "t_5561912_b_80157_tn_0"],
-            "routeShortName": [503, 403],
-            "routeId": [503, 403],
-            "directionId": [1, 1],
+            "routeShortName": ["503", "403"],
+            "routeId": ["503", "403"],
+            "directionId": ["1", "1"],
             "serviceId": ["c_69241_b_80157_d_31", "c_69241_b_80157_d_31"],
             "tripPatternId": [
                 "route_503_2561389_to_2561195_9e652c333c004f1edb920350d153a6f53514f9e293ed5cb3a473a51241a1f50d",
